#
# spec file for package golang
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global provider        github
%global provider_tld    com
%global project         gorilla
%global repo            websocket
%global provider_prefix %{provider}.%{provider_tld}/%{project}/%{repo}
%global import_path     %{provider_prefix}

Name:           golang-%{provider}-%{project}-%{repo}
Version:        0.0.0+git20170718.a69d9f6
Release:        3.1
Summary:        A WebSocket implementation for Go
License:        BSD-2-Clause
Group:          Development/Languages/Other
Url:            https://%{provider_prefix}
Source0:        %{repo}-%{version}.tar.xz
Source1:        rpmlintrc
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

BuildRequires:  golang-packaging
BuildRequires:  xz

%{go_nostrip}
%{go_provides}

%description
Gorilla WebSocket is a Go implementation of the WebSocket protocol.

It has some features that go-net doesn't have.

%prep
%setup -q -n %{repo}-%{version}

rm -rf example

%build
%goprep %{import_path}
%gobuild .

%install
%goinstall
%gosrc
%gofilelist

%check
%gotest %{import_path}

%files -f file.lst
%defattr(-,root,root)
%doc AUTHORS LICENSE README.md

%changelog
* Mon Aug 14 2017 thipp@suse.de
- Update to version 0.0.0+git20170718.a69d9f6:
  * Update compression documentation
  * benchmarks for write with compression enabled/disabled
  * Improve SetXHandler documentation
  * Change default and add API for compression level
  * Fix to compile on Go < 1.6
  * Fix compile error on Go < 1.6
  * Improve upgrade error messages
  * fix flate write pool size to work with best compression
  * remove test as HuffmanOnly compression level not defined in Go < 1.7
  * Add code snippet for EnableCompression in doc.go, change EnableWriteCompression()'s parameter to false since enableWriteCompression is true by default.
  * Change text/template to html/template in the examples
  * Prepared Messages (#211)
  * Improve examples
  * Add Go 1.8 to Travis config
  * Update cloneTLSConfig to use Go 1.8 Config.Clone method
  * Use bufio.Reader returned from hijack in upgrade
  * Fix formatting.
  * Use bufio.Writer returned from hijack in upgrade
  * enable client compression based on response header
  * Reduce memory used in chat example
  * doc: use ":=" when check error for conn.WriteMessage
  * distinguish Upgrader.Upgrade from Upgrade
  * implementing (some of) @garyburd's suggestions
  * Misc cleanup
* Tue Jan 10 2017 thipp@suse.de
- Update to version 0.0.0+git20161231.adf16b3:
  * Fix filewatch example
  * .travis.yml go vet fix.
  * Do not shallow copy crypto/tls.Config
  * Drop Go 1.3 from supported configurations
  * Fix Read() to return errUnexpectedEOF when EOF is received before all bytes in the frame have been read
  * Test truncated frames at all positions
  * Handle invalid close frames
  * Meaningful names for hub
  * Meaningful names for connection, message
  * Cleanup js in chat example
  * Reduce memory allocations in NextReader, NextWriter
  * Use single character receiver names in chat example
  * Revert "Reduce memory allocations in NextReader, NextWriter"
  * Reduce memory allocations in NextReader, NextWriter
  * Add Sec-WebSocket-Extensions header parser
  * Add Ping/Pong handler getter methods
  * Coalesce outbound messages in chat example
  * Implement RFC 6455, section 4.4
  * Add hooks to support RFC 7692 (per-message compression extension)
  * Add description to the chat example readme
  * Update hub.go
  * Improve chat example
  * Fix typos in chat example
  * Simplify dial TLS test
  * per message compression; only no context modes
  * Update README to reflect change of Go sub-repo websocket feature
  * compression: add tests, rename option
  * add cookie jar to dialer
  * Test w/ Go 1.7 on Travis
  * Improve mask performance
  * Update README.md
  * Improve chat example
  * Improve command example
  * Fix mask alignment
  * Improve write error handling
  * Add Conn.[Set]CloseHandler
  * Fix documentation
  * Improve WriteMessage fast path
  * pool flate writers
  * pool flate readers
  * Fix up README.md for command example.
  * Compression improvements
  * Add safe maskBytes
- Refactoring based on new packaging proposal
- Add rpmlintrc
* Sat Jul 16 2016 avvissu@yandex.by
- Get rid of source subpackage, no one use it
* Tue Mar 29 2016 avvissu@yandex.by
- Update to version 0.0.0+git20160313.e2e3d84:
  + Support proxy authorization for websocket client
  + Improve Upgrader.Upgrade doc
  + Update .travis.yml to build Go 1.6
  + Fix go vet warning
  + Run 'go vet' instead of 'go tool vet' in Travis
  + Remove Go 1.1 from Travis config
  + Add IsWebSocketUpgrade
  + Document that default ping handler can block
* Fri Mar 20 2015 i@marguerite.su
- initial version 0.0.0+git20150309.2dbddeb
